==> compton-conf_0.14.0.orig.tar.xz: compton-conf-0.14.0/translations/compton-conf_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Pengaturan Efek Khusus</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Radius blur untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Offset kiri untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Offset atas untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Keburaman untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Warna bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Perbaiki beberapa keanehan dengan jendela ARGB</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Setel topeng bayangan di balik jendela ke nol</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Jangan menggambar bayangan di jendela DND</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Hindari menggambar bayangan di jendela dock/panel</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Aktifkan bayangan sisi klien di jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Hindari menggambar bayangan pada semua jendela berbentuk</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Crop bayangan jendela yang dimaksimalkan dari layar tambahan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Opasitas</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Opasitas untuk menu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Opasitas standar jendela yang tidak aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Opasitas standar jendela yang aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Opasitas dari bilah judul dan border</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender backend: Ukuran langkah untuk gambar alfa
(Meningkatkannya bisa berakibat pada berkurangnya penggunaan sumber daya X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Redupkan jendela yang tidak aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Tingkat keredupan tidak tergantung pada opasitas jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Latar belakang blur di jendela transparan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Latar belakang blur di jendela buram dengan bingkai transparan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Radius blur tidak tergantung pada opasitas jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Pudar</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Pudarkan jendela saat perubahan opasitas</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Waktu antara langkah memudar dalam milidetik</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Perubahan opasitas antar langkah saat angsur jelas</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Perubahan opasitas antar langkah saat angsur pudar</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Cegah angsur jelas/pudar saat membuka/menutup jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Lainnya</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Backend perenderan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Tentang ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - alat konfigurasi untuk compton

Hak cipta (C) 2013
Pencipta: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> compton-conf_0.14.1.orig.tar.xz: compton-conf-0.14.1/translations/compton-conf_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Pengaturan Efek Khusus</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Radius blur untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Offset kiri untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Offset atas untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Keburaman untuk bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Warna bayangan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Perbaiki beberapa keanehan dengan jendela ARGB</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Setel topeng bayangan di balik jendela ke nol</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Jangan menggambar bayangan di jendela DND</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Hindari menggambar bayangan di jendela dock/panel</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Aktifkan bayangan sisi klien di jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Hindari menggambar bayangan pada semua jendela berbentuk</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Crop bayangan jendela yang dimaksimalkan dari layar tambahan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Opasitas</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Opasitas untuk menu</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Opasitas standar jendela yang tidak aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Opasitas standar jendela yang aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Opasitas dari bilah judul dan border</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender backend: Ukuran langkah untuk gambar alfa
(Meningkatkannya bisa berakibat pada berkurangnya penggunaan sumber daya X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Redupkan jendela yang tidak aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Tingkat keredupan tidak tergantung pada opasitas jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Latar belakang blur di jendela transparan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Latar belakang blur di jendela buram dengan bingkai transparan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Jangan biarkan radius blur tergantung pada opasitas jendela</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Pudar</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Pudarkan jendela saat perubahan opasitas</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Waktu antara langkah memudar dalam milidetik</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Perubahan opasitas antar langkah saat pudar aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Perubahan opasitas antar langkah saat pudar tidak aktif</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Hindari memudar jendela masuk/keluar saat membuka/menutup</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Lainnya</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Backend perenderan</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Tentang ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - alat konfigurasi untuk compton

Hak cipta (C) 2013
Pencipta: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
